Flexibility of BUs
========================

.. featurizer::  NConf20
    :id: NConf20
    :considers_geometry: True
    :considers_structure_graph: True
    :encodes_chemistry: False
    :scope: bu
    :scalar: True
